@@ -28,11 +28,11 @@
 #include "curb_macros.h"
 
 // These should be managed from the Rake 'release' task.
-#define CURB_VERSION   "0.9.11"
-#define CURB_VER_NUM   9011
-#define CURB_VER_MAJ   0
-#define CURB_VER_MIN   9
-#define CURB_VER_MIC   11
+#define CURB_VERSION   "1.0.5"
+#define CURB_VER_NUM   1005
+#define CURB_VER_MAJ   1
+#define CURB_VER_MIN   0
+#define CURB_VER_MIC   5
 #define CURB_VER_PATCH 0
 
 
@@ -49,6 +49,11 @@
   #define RHASH_SIZE(hash) RHASH(hash)->tbl->num_entries
 #endif
 
+// ruby 1.8 does not provide the macro
+#ifndef DBL2NUM
+  #define DBL2NUM(dbl) rb_float_new(dbl)
+#endif
+
 extern VALUE mCurl;
 
 extern void Init_curb_core();
