@@ -18,6 +18,8 @@ elsif !have_library('curl') or !have_header('curl/curl.h')
   fail <<-EOM
   Can't find libcurl or curl/curl.h
 
+  Make sure development libs (ie libcurl4-openssl-dev) are installed on the system.
+
   Try passing --with-curl-dir or --with-curl-lib and --with-curl-include
   options to extconf.
   EOM
@@ -341,6 +343,9 @@ have_constant :CURL_SSLVERSION_TLSv1_0
 have_constant :CURL_SSLVERSION_TLSv1_1
 have_constant :CURL_SSLVERSION_TLSv1_2
 
+# Added in 7.52.0
+have_constant :CURL_SSLVERSION_TLSv1_3
+
 have_constant "curlopt_ssl_verifypeer"
 have_constant "curlopt_cainfo"
 have_constant "curlopt_issuercert"
@@ -400,6 +405,39 @@ have_constant "curlopt_path_as_is"
 # added in 7.43.0
 have_constant "curlopt_pipewait"
 
+have_constant "curlopt_proxy_ssl_verifyhost"
+
+# protocol constants
+have_constant "curlproto_all"
+have_constant "curlproto_dict"
+have_constant "curlproto_file"
+have_constant "curlproto_ftp"
+have_constant "curlproto_ftps"
+have_constant "curlproto_gopher"
+have_constant "curlproto_http"
+have_constant "curlproto_https"
+have_constant "curlproto_imap"
+have_constant "curlproto_imaps"
+have_constant "curlproto_ldap"
+have_constant "curlproto_ldaps"
+have_constant "curlproto_pop3"
+have_constant "curlproto_pop3s"
+have_constant "curlproto_rtmp"
+have_constant "curlproto_rtmpe"
+have_constant "curlproto_rtmps"
+have_constant "curlproto_rtmpt"
+have_constant "curlproto_rtmpte"
+have_constant "curlproto_rtmpts"
+have_constant "curlproto_rtsp"
+have_constant "curlproto_scp"
+have_constant "curlproto_sftp"
+have_constant "curlproto_smb"
+have_constant "curlproto_smbs"
+have_constant "curlproto_smtp"
+have_constant "curlproto_smtps"
+have_constant "curlproto_telnet"
+have_constant "curlproto_tftp"
+
 if try_compile('int main() { return 0; }','-Wall')
   $CFLAGS << ' -Wall'
 end
