@@ -10,6 +10,14 @@ class TestCurbCurlEasy < Test::Unit::TestCase
     Curl.reset
   end
 
+  def test_nested_easy_methods
+    easy = Curl.get(TestServlet.url) {|http|
+      res = Curl.get(TestServlet.url + '/not_here')
+      assert_equal 404, res.code
+    }
+    assert_equal 200, easy.code
+  end
+
   def test_curlopt_stderr_with_file
     # does not work with Tempfile directly
     path = Tempfile.new('curb_test_curlopt_stderr').path
@@ -21,7 +29,7 @@ class TestCurbCurlEasy < Test::Unit::TestCase
     end
     output = File.read(path)
 
-    assert_match('HTTP/1.1 200 OK ', output)
+    assert_match(/HTTP\/1\.1\ 200\ OK(?:\ )?/, output)
     assert_match('Host: 127.0.0.1:9129', output)
   end
 
@@ -713,9 +721,9 @@ class TestCurbCurlEasy < Test::Unit::TestCase
     on_success_called = false
     curl.on_success {|c|
       on_success_called = true
-      assert_not_nil c.body_str
-      assert_equal "", c.header_str
-      assert_match(/^# DO NOT REMOVE THIS COMMENT/, c.body_str)
+      assert_not_nil c.body
+      assert_match(/Content-Length: /, c.head)
+      assert_match(/^# DO NOT REMOVE THIS COMMENT/, c.body)
     }
     curl.perform
     assert on_success_called, "Success handler not called" 
@@ -1139,7 +1147,7 @@ class TestCurbCurlEasy < Test::Unit::TestCase
     c = Curl::Easy.new($TEST_URL)
     c.on_success {|x| raise "error" }
     c.perform
-  rescue => e
+  rescue Curl::Err::AbortedByCallbackError => e
     assert_equal 'Curl::Err::AbortedByCallbackError', e.class.to_s
     c.close
   end
